# `py4etrics`

This module is for
* Truncated Regression
* Tobit Model
* Heckit Model

[Pythonで学ぶ入門計量経済学](https://py4etrics.github.io/) explains how to use it in Japanese. 
Or click its [Google translated version in English](https://translate.google.com/translate?sl=ja&tl=en&u=https%3A%2F%2Fpy4etrics.github.io) if you are happy with it. 

### How to Use
```
import py4etrics 
```

### How to Install
```
pip install git+https://github.com/spring-haru/py4etrics.git
```
or
```
git clone https://github.com/spring-haru/py4etrics.git
cd py4etrics
pip install .
```

